if(!isObject(ST_Chunk))
{
	datablock StaticShapeData(ST_Chunk)
	{
		shapeFile = "./chunk.dts";
		category = "Static Shapes";
	};
}

if(!isObject($ST::Data::Group))
{
	$ST::Data::Group = new SimGroup();
}

function ST_CreateChunk(%position)
{
	%z = mFloor( getWord(%position, 2) / 2 ) * 2;
	%position = getWords(%position, 0, 1) SPC %z;

	%brick = new fxDTSBrick()
	{
		position = %position;
		datablock = brick16Cube5Data;
		isPlanted = true;

		colorID = 45;

		printID = $printNameTable["ModTer/snow"];
		stackBL_ID = 888888;
	};
	
	%brick.setTrusted(1);
	%brick.plant();

	BrickGroup_888888.add(%brick);

	//%chunk = new StaticShape()
	//{
	//	datablock = ST_Chunk;
	//	position = %position;
	//	scale = "4 4 20";
	//	color = %color;
	//};
	//
	//%chunk.setNodeColor("ALL", %color);
	//
	//$ST::Data::Group.add(%chunk);
}

function ST_Clear()
{
	//$ST::Data::Group.chainDeleteAll();
	BrickGroup_888888.chainDeleteAll();
}

function ST_importTerrain(%name)
{
	%name = "base/terrain/" @ %name @ ".txt";

	if(!isFile(%name))
	{
		error("No such terrain file.");
		return;
	}

	%file = new fileObject();
	%file.openForRead(%name);

	$__ST::ClockRuntime = 0;
	__ST_importTerrainLoop(%file);
}

function __ST_importTerrainLoop(%file)
{
	if(%file.isEOF())
	{
		%file.close();
		%file.delete();
		return;
	}

	%line = %file.readLine();

	if(%line !$= "")
	{
		ST_CreateChunk(%line);
	}

	$__ST::importTerrainLoop = schedule(($__ST::ClockRuntime++ % 3) ? 1 : 0, 0, __ST_importTerrainLoop, %file);
}

function ST_cancelImport()
{
	cancel($__ST::importTerrainLoop);
}

function ST_FixHoles()
{
	deleteVariables("$__ST::holeFix*");
	for(%a = 0; %a < BrickGroup_888888.getCount(); %a++)
	{
		if((%obj = BrickGroup_888888.getObject(%a)).holeFixed)
		{
			continue;
		}

		%pos = %obj.getPosition();
		%xy = getWords(%pos, 0, 1);
		%z = getWord(%pos, 2);

		$__ST::holeFixPos[ %xy ] = %z;
	}

	schedule(2000, 0, __ST_FixHolesTwo);
}

function __ST_FixHolesTwo()
{
	//         +
	//   -------------
	//   | A | B | C |
	//   -------------
	// - | D | E | F | +
	//   -------------
	//   | G | H | I |
	//   -------------
	//         -

	for(%a = 0; %a < BrickGroup_888888.getCount(); %a++)
	{
		if((%obj = BrickGroup_888888.getObject(%a)).holeFixed)
		{
			continue;
		}

		%pos = %obj.getPosition();
		%xy = getWords(%pos, 0, 1);
		%z = getWord(%pos, 2) - 16;

		%add[0] = "8 0";
		%add[1] = "0 8";
		%add[2] = "-8 0";
		%add[3] = "0 -8";

		for(%i = 0; %i < 4; %i++)
		{
			%xy2 = getWords(VectorAdd(%xy, %add[%i]), 0, 1);
			%z2 = $__ST::holeFixPos[ %xy2 ];

			if(strLen(%z2) && %z2 < %z)
			{
				%hole = true;
				%holeCount++;
				break;
			}
		}

		if(%hole)
		{
			%newpos = %xy SPC %z;
			ST_CreateChunk(%newpos);
		}
	}

	announce("Fixed" SPC %holeCount SPC "holes.");
}